# Table of Contents

- [to-dos-administration](<./to-dos-administration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [To-Dos (Administration)](<./To-Dos-Administration.md>)
  - [Introduction](<./To-Dos-Administration/Introduction.md>)
  - [Creating Approval To-Dos](<./To-Dos-Administration/Creating-Approval-To-Dos.md>)
  - [Managing To-Dos](<./To-Dos-Administration/Managing-To-Dos.md>)
  - [Modifying To-Do Items](<./To-Dos-Administration/Modifying-To-Do-Items.md>)
  - [Was this page helpful?](<./To-Dos-Administration/Was-this-page-helpful.md>)
  - [We'd love your feedback!](<./To-Dos-Administration/Wed-love-your-feedback.md>)
